﻿using System.ComponentModel;

namespace IgDoughnutTester
{
    /// <summary>
    /// Base class for objects that support raising property change notifications.
    /// </summary>
    public abstract class NotificationObject : INotifyPropertyChanged
    {
        #region Events

        /// <summary>
        /// Fires when a property value changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        #region Methods

        /// <summary>
        /// Notifies listeners that a property value has changed.
        /// </summary>
        /// <param name="propertyName">The name of the property that changed.</param>
        protected void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion
    }
}
